@@ -21,6 +21,14 @@ class X_API:
         response = self._client.open_api_do("POST", "", json=post_data).json()
         return response["data"][0]
 
+    def callback_task(
+            self,
+            task_id: str
+            post_data: Dict[str, Any]
+    ) -> Dict[str, Any]:
+        response = self._client.open_api_do("POST", f"pretrain/task/{task_id}/callback", json=post_data).json()
+        return response
+
     def delete_dataset(
             self,
             dataset_id: str
